// ===========================================================================
// CONTENT  : CLASS AdminServer
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 08/08/2006
// HISTORY  :
//  08/08/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.admin ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pf.net.RequestProcessor;
import org.pf.net.TextRequestProcessor;
import org.pf.net.TextRequestServer;
import org.pf.net.TextSocketConnection;
import org.pfsw.tools.beluga.common.LoggerService;
import org.pfsw.tools.beluga.ldap.server.LDAPServer;

/**
 * This server is responsible to handle administration requests
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class AdminServer extends TextRequestServer
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	protected static final String I_SERVER_LISTENING		= "BAS0001" ;
	protected static final String I_SERVER_STOPPED			= "BAS0002" ;
	protected static final String E_PORT_IN_USE					= "BAS0003" ;

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
	private long connCounter = 1 ; 
	
  private AdminServerConfiguration config = null ;
  protected AdminServerConfiguration getConfig() { return config ; }
  protected void setConfig( AdminServerConfiguration newValue ) { config = newValue ; }

  private LDAPServer ldapServer = null ;
  protected LDAPServer getLdapServer() { return ldapServer ; }
  protected void setLdapServer( LDAPServer newValue ) { ldapServer = newValue ; }
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
	/**
	 * Initialize the new instance with a configuration
	 */
	public AdminServer(AdminServerConfiguration configuration, LDAPServer ldapServer)
	{
		super(configuration.getPort());
		this.setConfig(configuration);
		this.setLdapServer(ldapServer);
	} // AdminServer() 

	// -------------------------------------------------------------------------

	// =========================================================================
	// PUBLIC INSTANCE METHODS
	// =========================================================================
	/**
	 * Starts the server.
	 */
	public void start()
	{
		if (this.initialize())
		{
			this.logger().logInfo(I_SERVER_LISTENING, "Admin server listening on port {0}", Integer.toString(this.port()));
			try
			{
				this.listen();
				this.logger().logInfo(I_SERVER_STOPPED, "Admin server stopped.");
			}
			finally
			{
				this.close();
			}
		}
		else
		{
			this.logger().logInfo(E_PORT_IN_USE,
					"Cannot open server socket on port {0}. Admin Server probably already running.",
					Integer.toString(this.port()));
		}
	} // start() 

	// -------------------------------------------------------------------------

	/**
	 * Stops the LDAP server
	 */
	public void shutdownLdapServer()
	{
		ldapServer.stop();
	} // shutdownLdapServer() 

	// -------------------------------------------------------------------------

	/**
	 * Stops this admin server
	 */
	public void shutdown()
	{
		this.done(true);
		this.close();
	} // shutdown() 

	// -------------------------------------------------------------------------

	// =========================================================================
	// PROTECTED INSTANCE METHODS
	// =========================================================================
	protected TextRequestProcessor createRequestProcessor(TextSocketConnection connection)
	{
		return new AdminTask(connection, this);
	} // createRequestProcessor() 

	// -------------------------------------------------------------------------

	protected Thread createProcessingThread(RequestProcessor requestProcessor)
	{
		Thread thread;

		thread = super.createProcessingThread(requestProcessor);
		thread.setName("Admin-" + connCounter++);
		if (connCounter > (Long.MAX_VALUE - 10))
		{
			connCounter = 1;
		}
		return thread;
	} // createProcessingThread() 

	// -------------------------------------------------------------------------

	protected LoggerService logger()
	{
		return LoggerService.getLogger();
	} // logger() 

	// -------------------------------------------------------------------------

} // class AdminServer 
