// ===========================================================================
// CONTENT  : CLASS BindRequest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 08/07/2004
// HISTORY  :
//  08/07/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.messages ;

// ===========================================================================
// IMPORTS
// ===========================================================================

/**
 * Represents a bind request from a client.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class BindRequest extends RequestMessage
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private String distinguishedName = null ;
  protected String getDistinguishedName() { return distinguishedName ; }
  protected void setDistinguishedName( String newValue ) { distinguishedName = newValue ; }
  
  private byte[] pwd = null ;
  protected byte[] getPwd() { return pwd ; }
  protected void setPwd( byte[] newValue ) { pwd = newValue ; }	
  // =========================================================================
  // CLASS METHODS
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with the raw data transmitted by the client.
   */
  public BindRequest()
  {
    super() ;
  } // BindRequest()
  
  // -------------------------------------------------------------------------

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Returns true because this is a bind request.
   */
  public boolean isBindRequest() 
	{
		return true ;
	} // isBindRequest()

	// -------------------------------------------------------------------------
  
  /**
   * Return the distinguished name for the user to bind against the directory
   */
  public String getDN() 
	{
		return this.getDistinguishedName() ;
	} // getDN()

	// -------------------------------------------------------------------------
  
  /**
   * Set the distinguished name for the user to bind against the directory
   */
  public void setDN( String dn ) 
	{
		this.setDistinguishedName( dn ) ;
	} // setDN()

	// -------------------------------------------------------------------------
  
  /**
   * Return the password for the user to bind against the directory
   */
  public byte[] getPassword() 
	{
		return this.getPwd() ;
	} // getPassword()

	// -------------------------------------------------------------------------
  
  /**
   * Set the password for the user to bind against the directory
   */
  public void setPassword( byte[] password ) 
	{
		this.setPwd( password ) ;
	} // setPassword()

	// -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected String getName() 
	{
		return "BindRequest" ;
	} // getName() 

	// -------------------------------------------------------------------------
  
  protected void appendParameter( StringBuffer buffer ) 
	{
		buffer.append( this.getDN() ) ;
	} // appendParameter() 

	// -------------------------------------------------------------------------
  
} // class BindRequest
