// ===========================================================================
// CONTENT  : CLASS ModifyRequest
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 29/07/2006
// HISTORY  :
//  29/07/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.messages ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.ArrayList;
import java.util.List;

import org.pf.directory.DistinguishedName;
import org.pf.util.CollectionUtil;

/**
 * Message for modify requests
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class ModifyRequest extends RequestMessage
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private DistinguishedName DN = null ;
  public DistinguishedName getDN() { return DN ; }
  public void setDN( DistinguishedName newValue ) { DN = newValue ; }

  private List modifications = new ArrayList(20) ;
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public ModifyRequest()
  {
    super() ;
  } // ModifyRequest() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public void addModification( AttributeModificationDefinition modification ) 
	{
  	if ( modification != null )
		{
  		modifications.add( modification ) ;
		}
	} // addModification() 
	
	// -------------------------------------------------------------------------

  public AttributeModificationDefinition[] getModificationDefinitions() 
	{
		return (AttributeModificationDefinition[])this.coll().toArray( modifications ) ;
	} // getModificationDefinitions() 
	
	// -------------------------------------------------------------------------
  
  public boolean isModifyRequest()
  {
  	return true ;
  } // isModifyRequest()
  
  // -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
	protected String getName()
	{
		return "ModifyRequest" ;
	} // getName() 
	
	// -------------------------------------------------------------------------

	protected CollectionUtil coll() 
	{
		return CollectionUtil.current() ;
	} // coll() 
	
	// -------------------------------------------------------------------------
	
} // class ModifyRequest 
