// ===========================================================================
// CONTENT  : CLASS SearchRequest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 09/07/2004
// HISTORY  :
//  09/07/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.messages ;

// ===========================================================================
// IMPORTS
// ===========================================================================

/**
 * Represents a LDAP serach request message
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class SearchRequest extends RequestMessage
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	public static final int SCOPE_BASE_OBJECT			= 0 ;
	public static final int SCOPE_SINGLE_LEVEL		= 1 ;
	public static final int SCOPE_WHOLE_SUBTREE		= 2 ;

	public static final int DEREF_NEVER						= 0 ;
	public static final int DEREF_IN_SEARCH				= 1 ;
	public static final int DEREF_FINDING_BASE		= 2 ;
	public static final int DEREF_ALWAYS					= 3 ;
	
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private String baseDN = null ;
  public String getBaseDN() { return baseDN ; }
  public void setBaseDN( String newValue ) { baseDN = newValue ; }
  
  private int scope = SCOPE_BASE_OBJECT ;
  public int getScope() { return scope ; }
  public void setScope( int newValue ) { scope = newValue ; }
  
  private int derefAliases = DEREF_NEVER ;
  public int getDerefAliases() { return derefAliases ; }
  public void setDerefAliases( int newValue ) { derefAliases = newValue ; }  
  
  private int sizeLimit = 0 ;
  public int getSizeLimit() { return sizeLimit ; }
  public void setSizeLimit( int newValue ) { sizeLimit = newValue ; }
  
  private int timeLimit = 0 ;
  public int getTimeLimit() { return timeLimit ; }
  public void setTimeLimit( int newValue ) { timeLimit = newValue ; }

  private boolean typesOnly = false ;
  public boolean getTypesOnly() { return typesOnly ; }
  public void setTypesOnly( boolean newValue ) { typesOnly = newValue ; }  
  
  private String filter = null ;
  public String getFilter() { return filter ; }
  public void setFilter( String newValue ) { filter = newValue ; }
  
  private String[] attributeNames = null ;
  public String[] getAttributeNames() { return attributeNames ; }
  public void setAttributeNames( String[] newValue ) { attributeNames = newValue ; }  
  // =========================================================================
  // CLASS METHODS
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public SearchRequest()
  {
    super() ;
  } // SearchRequest() 

  // -------------------------------------------------------------------------
  
  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Returns true if the receiver is a search request.
   */
  public boolean isSearchRequest() 
	{
		return true ;
	} // isSearchRequest() 

	// -------------------------------------------------------------------------
  
  /**
   * Returns true if the scope of this search is the base object only
   */
  public boolean isScopeBaseObject() 
	{
		return SCOPE_BASE_OBJECT == this.getScope() ;
	} // isScopeBaseObject() 

	// -------------------------------------------------------------------------
  
  /**
   * Returns true if the scope of this search is the single level
   */
  public boolean isScopeSingleLevel() 
	{
		return SCOPE_SINGLE_LEVEL == this.getScope() ;
	} // isScopeSingleLevel() 

	// -------------------------------------------------------------------------
  
  /**
   * Returns true if the scope of this search is the whole subtree
   */
  public boolean isScopeWholeSubtree() 
	{
		return SCOPE_WHOLE_SUBTREE == this.getScope() ;
	} // isScopeWholeSubtree() 

	// -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

	protected String getName()
	{
		return "SearchRequest" ;
	} // getName() 
	
	// -------------------------------------------------------------------------
	
	protected void appendParameter( StringBuffer buffer )
	{
		buffer.append( "base-dn: " ) ;
		buffer.append( this.getBaseDN() ) ;
		buffer.append( " ; filter: " ) ;
		buffer.append( this.getFilter() ) ;
	} // appendParameter() 
	
	// -------------------------------------------------------------------------
	
} // class SearchRequest 
