// ===========================================================================
// CONTENT  : CLASS LDAPControl
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 25/06/2006
// HISTORY  :
//  25/06/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.protocol ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import javax.naming.ldap.Control ;

/**
 * Represents a single controls as it can be used with requests and
 * responses.
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class LDAPControl implements Control
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
	private String oid = null ;
	private boolean critical = false ;
	private String value = null ;
	
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public LDAPControl( String id )
  {
    super() ;
    this.setID( id ) ;
  } // LDAPControl() 


  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public byte[] getEncodedValue()
  {
  	if ( value == null )
		{
			return null ;
		}
  	return value.getBytes() ;
  } // getEncodedValue()

  // -------------------------------------------------------------------------
  
  public String getID()
  {
  	return oid;
  } // getID()
  
  // -------------------------------------------------------------------------
  
  public boolean isCritical()
  {
  	return critical;
  } // isCritical()

  // -------------------------------------------------------------------------
  
  public String getValue() 
	{
		return value ;
	} // getValue()
	
	// -------------------------------------------------------------------------
  
  public String toString() 
	{
		StringBuffer buffer ;
		
		buffer = new StringBuffer(30);
		buffer.append( "LDAPControl(" ) ;
		buffer.append( this.getID() ) ;
		buffer.append( "," ) ;
		buffer.append( this.isCritical() ? "creitical" : "uncritical" ) ;
		buffer.append( "," ) ;
		if ( this.getValue() != null )
		{
			buffer.append( this.getValue() ) ;
		}
		buffer.append( ")" ) ;
		return buffer.toString() ;
	} // toString()
	
	// -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected void setCritical( boolean yesOrNo ) 
	{
		critical = yesOrNo ;
	} // setCritical()
	
	// -------------------------------------------------------------------------
  
  protected void setID( String id ) 
	{
		oid = id ;
	} // setID()
	
	// -------------------------------------------------------------------------
  
  protected void setValue( String newValue ) 
	{
		value = newValue ;
	} // setValue()
	
	// -------------------------------------------------------------------------
  
  protected void setValue( byte[] newValue ) 
  {
  	this.setValue( new String( newValue ) ) ;
  } // setValue()
  
  // -------------------------------------------------------------------------
  
} // class LDAPControl 
